@@ -31,15 +31,15 @@
 #'  should be metric or label, not surface.)
 #'
 #'  If \code{cortexL_mwall} is not provided, \code{cortexL} should have data for
-#'  all vertices on the left cortical surface (\eqn{V_L x T} data matrix). There
+#'  all vertices on the left cortical surface (\eqn{V_L \times T} data matrix). There
 #'  will not be a mask for the medial wall. Not providing the medial wall mask
 #'  is appropriate for ".dlabels.nii" files where the medial wall may have its
 #'  own label and therefore should not be treated as missing data.
 #'
 #'  If \code{cortexL_mwall} is provided, \code{cortexL} should either have data
-#'  for all vertices on the left cortical surface (\eqn{V_L x T} data matrix, with
+#'  for all vertices on the left cortical surface (\eqn{V_L \times T} data matrix, with
 #'  filler values e.g. \code{0} or \code{NaN} for medial wall vertices), or have data
-#'  only for non-medial wall vertices (\eqn{(V_L - mwall_L) x T} data matrix).
+#'  only for non-medial wall vertices (\eqn{(V_L - mwall_L) \times T} data matrix).
 #'  The medial wall mask will be the \code{0} values in \code{cortexL_mwall}.
 #'  The medial wall mask should be provided whenever the medial wall should be
 #'  treated as missing data.
@@ -51,15 +51,15 @@
 #'  should be metric or label, not surface.)
 #'
 #'  If \code{cortexR_mwall} is not provided, \code{cortexR} should have data for
-#'  all vertices on the right cortical surface (\eqn{V_R x T} data mre
+#'  all vertices on the right cortical surface (\eqn{V_R \times T} data mre
 #'  will not be a mask for the medial wall. Not providing the medial wall mask
 #'  is appropriate for ".dlabels.nii" files where the medial wall may have its
 #'  own label and therefore should not be treated as missing data.
 #'
 #'  If \code{cortexR_mwall} is provided, \code{cortexR} should either have data
-#'  for all vertices on the right cortical surface (\eqn{V_R x T} data matrix, with
+#'  for all vertices on the right cortical surface (\eqn{V_R \times T} data matrix, with
 #'  filler values e.g. \code{0} or \code{NaN} for medial wall vertices), or have data
-#'  only for non-medial wall vertices (\eqn{(V_R - mwall_R) x T} data matrix).
+#'  only for non-medial wall vertices (\eqn{(V_R - mwall_R) \times T} data matrix).
 #'  The medial wall mask will be the \code{0} values in \code{cortexR_mwall}.
 #'  The medial wall mask should be provided whenever the medial wall should be
 #'  treated as missing data.
@@ -68,19 +68,19 @@
 #'  \code{V_L} should match \code{V_R}.
 #' @param subcortVol,subcortLabs,subcortMask \code{subcortVol} represents the
 #'  data values of the subcortex. It is either a NIFTI file path, 3D/4D data array
-#'  (\eqn{i x j x k x T}), or a vectorized data matrix (\eqn{V_S} voxels by \eqn{T}
+#'  (\eqn{i \times j \times k \times T}), or a vectorized data matrix (\eqn{V_S} voxels by \eqn{T}
 #'  measurements). If it's vectorized, the voxels should be in spatial order
 #'  (\eqn{i} index increasing fastest, then \eqn{j}, then \eqn{k}).
 #'
 #'  \code{subcortLabs} represents the brainstructure labels of each voxel: see
 #'  \code{\link{substructure_table}}. It is either a NIFTI file path, 3D data array
-#'  (\eqn{i x j x k}) of integer brainstructure indices, or a \eqn{V_S} length
+#'  (\eqn{i \times j \times k}) of integer brainstructure indices, or a \eqn{V_S} length
 #'  vector in spatial order with brainstructure names as factors or integer
 #'  indices. The indices should be 3-21 (1 and 2 correspond to left and right
 #'  cortex, respectively) or 1-19 (cortex labels omitted), with 0 representing
 #'  out-of-mask voxels.
 #'
-#'  \code{subcortMask} is NIFTI file path or logical 3D data array (\eqn{i x j x k})
+#'  \code{subcortMask} is NIFTI file path or logical 3D data array (\eqn{i \times j \times k})
 #'  where \code{TRUE} values indicate subcortical voxels (in-mask). If it is not
 #'  provided, the mask will be inferred from voxels with labels \code{0},
 #'  \code{NA}, or \code{NaN} in \code{subcortLabs}. If \code{subcortLabs} are
@@ -147,6 +147,27 @@ make_xifti <- function(
   if (is.fname(surfL)) { surfL <- format_path(surfL, read_dir, mode=4) }
   if (is.fname(surfR)) { surfR <- format_path(surfR, read_dir, mode=4) }
 
+  if (is.fname(cortexL)) {
+    if (!(endsWith(cortexL, "label.gii") || endsWith(cortexL, "func.gii"))) {
+      warning("File path for `cortexL`, '", cortexL, "', does not look like metric GIFTI data.")
+    }
+  }
+  if (is.fname(cortexR)) {
+    if (!(endsWith(cortexR, "label.gii") || endsWith(cortexR, "func.gii"))) {
+      warning("File path for `cortexR`, '", cortexR, "', does not look like metric GIFTI data.")
+    }
+  }
+  if (is.fname(surfL)) {
+    if (!(endsWith(surfL, "surf.gii"))) {
+      warning("File path for `surfL`, '", surfL, "', does not look like GIFTI surface geometry.")
+    }
+  }
+  if (is.fname(surfR)) {
+    if (!(endsWith(surfR, "surf.gii"))) {
+      warning("File path for `surfR`, '", surfR, "', does not look like GIFTI surface geometry.")
+    }
+  }
+
   # Template.
   xifti <- template_xifti()
 
