@@ -12,7 +12,7 @@
 #'  Surfaces are required for each hemisphere in the CIFTI. If they are not 
 #'  provided, the default inflated surfaces will be used. 
 #' 
-#'  Conversion for sigma: \eqn{\sigma * 2 * sqrt(2*log(2)) = FWHM}
+#'  Conversion for sigma: \eqn{\sigma \times 2 \times \sqrt(2 \times \log(2)) = FWHM}
 #' 
 #' @param x The CIFTI file name or \code{"xifti"} object to smooth.
 #' @param cifti_target_fname File name for the smoothed CIFTI. If
@@ -35,6 +35,7 @@
 #' @return The \code{cifti_target_fname}, invisibly, if \code{x} was a CIFTI
 #'  file name. A \code{"xifti"} object if \code{x} was a \code{"xifti"} object.
 #' 
+#' @family manipulating xifti
 #' @family common
 #' @export
 #'
@@ -64,7 +65,7 @@ smooth_cifti <- function(
     }
 
     res <- infer_resolution(x)
-    if (any(res %in% c(NA, NaN))) {
+    if (any(is.na(res))) {
       stop("Cannot smooth because the resolution could not be inferred.")
     } else if (!(any(res == 0)) && res[1] != res[2]) {
       stop("Cannot smooth because the left and right cortex have unequal inferred resolutions: ", res[1], " and ", res[2], ".")
