@@ -1,48 +1,19 @@
-#' Undo a volumetric mask
+#' Undo the volumetric mask to the subcortex
 #' 
-#' Un-applies a mask to vectorized data to yield its volumetric representation.
-#'  The mask and data should have compatible dimensions: the number of rows in
-#'  \code{dat} should equal the number of locations within the \code{mask}.
-#'  This is used for the subcortical CIFTI data.
+#' Un-applies the mask to the subcortical data in a \code{"xifti"} to yield its
+#'  volumetric representation. 
 #' 
-#' @param dat Data matrix with locations along the rows and measurements along 
-#'  the columns. If only one set of measurements were made, this may be a 
-#'  vector.
-#' @param mask Volumetric binary mask. \code{TRUE} indicates voxels inside the
-#'  mask.
+#' @inheritParams xifti_Param
 #' @param fill The value for locations outside the mask. Default: \code{NA}.
 #'
 #' @return The 3D or 4D unflattened volume array
 #'
 #' @export
 #' 
-unmask_subcortex <- function(dat, mask, fill=NA) {
-
-  # Check that dat is a vector or matrix.
-  if (is.vector(dat) || is.factor(dat)) { dat <- matrix(dat, ncol=1) }
-  stopifnot(length(dim(dat)) == 2)
-
-  # Check that mask is numeric {0, 1} or logical, and is 3D.
-  if (is.numeric(mask)) {
-    mask_vals <- unique(as.vector(mask))
-    stopifnot(length(mask_vals) <= 2)
-    stopifnot(all(mask_vals %in% c(0,1)))
-    mask <- array(as.logical(mask), dim=dim(mask))
-  }
-  stopifnot(length(dim(mask)) == 3)
-
-  # Other checks.
-  stopifnot(is.vector(fill) && length(fill)==1)
-  stopifnot(sum(mask) == nrow(dat))
-
-  # Make volume and fill.
-  vol <- array(fill, dim=c(dim(mask), ncol(dat)))
-  for (ii in seq_len(ncol(dat))) {
-    vol[,,,ii][mask] <- dat[,ii]
-  }
-  if (ncol(dat)==1) { vol <- vol[,,,1] }
-
-  vol
+unmask_subcortex <- function(xifti, fill=NA) {
+  stopifnot(is.xifti(xifti))
+  if (is.null(xifti$data$subcort)) { stop("No subcortical data to unmask.") }
+  unvec_vol(xifti$data$subcort, xifti$meta$subcort$mask, fill=fill)
 }
 
 #' Pad a 3D Array
@@ -210,4 +181,50 @@ write_label_table <- function(label_table, fname){
   label_table <- apply(label_table, 1, paste0, collapse=" ")
   out <- c(rbind(names(label_table), label_table))
   writeLines(out, fname)
-}
\ No newline at end of file
+}
+
+#' Convert vectorized data back to volume
+#' 
+#' Un-applies a mask to vectorized data to yield its volumetric representation.
+#'  The mask and data should have compatible dimensions: the number of rows in
+#'  \code{dat} should equal the number of locations within the \code{mask}.
+#' 
+#' @param dat Data matrix with locations along the rows and measurements along 
+#'  the columns. If only one set of measurements were made, this may be a 
+#'  vector.
+#' @param mask Volumetric binary mask. \code{TRUE} indicates voxels inside the
+#'  mask.
+#' @param fill The value for locations outside the mask. Default: \code{NA}.
+#'
+#' @return The 3D or 4D unflattened volume array
+#'
+#' @keywords internal
+#' 
+unvec_vol <- function(dat, mask, fill=NA) {
+
+  # Check that dat is a vector or matrix.
+  if (is.vector(dat) || is.factor(dat)) { dat <- matrix(dat, ncol=1) }
+  stopifnot(length(dim(dat)) == 2)
+
+  # Check that mask is numeric {0, 1} or logical, and is 3D.
+  if (is.numeric(mask)) {
+    mask_vals <- unique(as.vector(mask))
+    stopifnot(length(mask_vals) <= 2)
+    stopifnot(all(mask_vals %in% c(0,1)))
+    mask <- array(as.logical(mask), dim=dim(mask))
+  }
+  stopifnot(length(dim(mask)) == 3)
+
+  # Other checks.
+  stopifnot(is.vector(fill) && length(fill)==1)
+  stopifnot(sum(mask) == nrow(dat))
+
+  # Make volume and fill.
+  vol <- array(fill, dim=c(dim(mask), ncol(dat)))
+  for (ii in seq_len(ncol(dat))) {
+    vol[,,,ii][mask] <- dat[,ii]
+  }
+  if (ncol(dat)==1) { vol <- vol[,,,1] }
+
+  vol
+}
