@@ -63,7 +63,7 @@ write_subcort_nifti <- function(
   }
 
   # Data.
-  subcortVol <- unmask_subcortex(subcortVol, subcortMask, fill=fill)
+  subcortVol <- unvec_vol(subcortVol, subcortMask, fill=fill)
   ## https://github.com/jonclayden/RNifti/issues/5
   if (!is.null(trans_mat)) {
     subcortVol <- RNifti::`sform<-`(subcortVol, trans_mat)
@@ -112,7 +112,7 @@ write_subcort_nifti <- function(
   # Labels.
   stopifnot(is.subcort_labs(subcortLabs))
   subcortLabs <- as.numeric(subcortLabs) #- 2
-  subcortLabs <- unmask_subcortex(subcortLabs, subcortMask, fill=fill)
+  subcortLabs <- unvec_vol(subcortLabs, subcortMask, fill=fill)
   if (!is.null(trans_mat)) {
     subcortLabs <- RNifti::`sform<-`(subcortLabs, trans_mat)
   }
